#!/bin/bash
############
# Usage: bash archiving_and_split.sh
# Goal: For the audiocité.net corpus, permits to archive the metadata in the "FIRSTARCHIVE"
# and all the audio files in the next archives with a maximum size of 10GB each
# Date: 14/02/2023
# Author: Soline Felice, Laboratoire d'Informatique de Grenoble
############


# Initialization of the variables permiting to leave the loop
n=0

size_wanted=10000000000 # Final size wanted (10 GB == 10 000 MB)

FIRSTARCHIVE="/projets/TO_REMOVE/Soline/Test_Archive_Split/audiocite_test_split_0.zip"

ARCHIVE=/projets/TO_REMOVE/Soline/Test_Archive_Split/audiocite_test_split_$n.zip

### First Loop : Zip the first archive (only the metadata)

if [[ "$ARCHIVE" == "$FIRSTARCHIVE" ]] ; then  # If the archive is the first one being created
    zip $ARCHIVE scripts/*.py metadata/* README.md archiving_and_split.sh datasheet_audiocite.pdf # Archiving of the metadata
    n=$((n+1))  # n permits to count the number of archives and to update the name of the archive 
    ARCHIVE=/projets/TO_REMOVE/Soline/Test_Archive_Split/audiocite_test_split_$n.zip
fi

actual_archive_size=$(7z a -mmt -tzip $ARCHIVE $d*.mp3 |  grep "Physical Size" | awk -F'= ' '{print $2}') # Get the archive size
next_dir_size=$(7z a -mmt -tzip $ARCHIVE $d*.mp3 |  grep "files," | awk -F' ' '{print $3}') # Get the next directory size
futur_potential_archive_size=$((actual_archive_size+next_dir_size)) # Get the futur size of th archive if the next directory will be put in this archive

if [[ "$actual_archive_size" == "" ]] ; then  # Loop to handle when the archive's size doesn't have a value (if it's empty)
    declare -i actual_archive_size=0
fi

### Second Loop : Zip the other archives from the directory wavs/*/extracted/ (10Go of .mp3 files)

for d in wavs/*/extracted/; do
    actual_archive_size=$(7z a -mmt -tzip $ARCHIVE $d*.mp3 |  grep "Physical Size" | awk -F'= ' '{print $2}')  # Get the archive size
    next_dir_size=$(7z a -mmt -tzip $ARCHIVE $d*.mp3 |  grep "files," | awk -F' ' '{print $3}') # Get the next directory size
    futur_potential_archive_size=$((actual_archive_size+next_dir_size)) # Get the futur size of th archive if the next directory will be put in this archive

    if [ "$futur_potential_archive_size" -le "$size_wanted" ]; then # While the archive's size is lower than the size wanted (10 Mo per archive)

        7z a -mmt -tzip $ARCHIVE $d*.mp3  # Adding to the archive by multi-tread (using multiple CPU) directory with mp3 inside (only the .mp3 files)
        actual_archive_size=$(7z a -mmt -tzip $ARCHIVE $d*.mp3 |  grep "Physical Size" | awk -F'= ' '{print $2}')  # Get the archive size
        next_dir_size=$(7z a -mmt -tzip $ARCHIVE $d*.mp3 |  grep "files," | awk -F' ' '{print $3}') # Get the next directory size
        futur_potential_archive_size=$((actual_archive_size+next_dir_size)) # Get the futur size of th archive if the next directory will be put in this archive
    else
        n=$((n+1))
        ARCHIVE=/projets/TO_REMOVE/Soline/Test_Archive_Split/audiocite_test_split_$n.zip
    fi

done

if [[ "$actual_archive_size" == "" ]] ; then  # Loop to handle when the archive's size doesn't have a value 
    declare -i actual_archive_size=0
fi

### Third Loop : Zip the other archives from the directory wavs/*/ (10Go of .mp3 files)

for d in wavs/*/; do

    actual_archive_size=$(7z a -mmt -tzip $ARCHIVE $d*.mp3 |  grep "Physical Size" | awk -F'= ' '{print $2}')  # Get the archive size
    next_dir_size=$(7z a -mmt -tzip $ARCHIVE $d*.mp3 |  grep "files," | awk -F' ' '{print $3}')
    futur_potential_archive_size=$((actual_archive_size+next_dir_size))

    if [ "$futur_potential_archive_size" -le "$size_wanted" ]; then          
        7z a -mmt -tzip $ARCHIVE $d*.mp3  # Adding to the archive by multi-tread (using multiple CPU) directory with mp3 inside (only the .mp3 files)
        actual_archive_size=$(7z a -mmt -tzip $ARCHIVE $d*.mp3 |  grep "Physical Size" | awk -F'= ' '{print $2}')  # Get the archive size
        next_dir_size=$(7z a -mmt -tzip $ARCHIVE $d*.mp3 |  grep "files," | awk -F' ' '{print $3}')
        futur_potential_archive_size=$((actual_archive_size+next_dir_size))
    else
        n=$((n+1))
        ARCHIVE=/projets/TO_REMOVE/Soline/Test_Archive_Split/audiocite_test_split_$n.zip
    fi

done